@@ -13,19 +13,19 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <poppler.h>
 
 #ifndef _OUTLINE_H_
-#define _OUTLINE_H_
+#    define _OUTLINE_H_
 
 G_BEGIN_DECLS
 
-GtkWidget *pgd_outline_create_widget (PopplerDocument *document);
+GtkWidget *pgd_outline_create_widget(PopplerDocument *document);
 
 G_END_DECLS
 
-#endif /* _OUTLINE_H_ */ 
+#endif /* _OUTLINE_H_ */
